@@ -57,8 +57,10 @@
 #include <QtMultimedia/qmediaavailabilitycontrol.h>
 #include <QtMultimedia/qaudioinput.h>
 #include <QtMultimedia/qvideosurfaceformat.h>
+#include <QtMultimedia/qcameraexposure.h>
 #include <QtMultimedia/qmediacontainercontrol.h>
 #include <QtMultimedia/qcameraviewfindersettingscontrol.h>
+#include <QtMultimedia/qcameraimageprocessing.h>
 #include <QtMultimedia/qmediacontrol.h>
 #include <QtMultimedia/qimageencodercontrol.h>
 #include <QtMultimedia/qmediaplayercontrol.h>
@@ -70,6 +72,7 @@
 #include <QtMultimedia/qmediatimerange.h>
 #include <QtMultimedia/qcamerafocus.h>
 #include <QtMultimedia/qmediastreamscontrol.h>
+#include <QtMultimedia/qcameraflashcontrol.h>
 #include <QtMultimedia/qabstractvideobuffer.h>
 #include <QtMultimedia/qmediacontent.h>
 #include <QtMultimedia/qaudiorolecontrol.h>
@@ -80,8 +83,8 @@
 #include <QtMultimedia/qcameracontrol.h>
 #include <QtMultimedia/qaudiodecoder.h>
 #include <QtMultimedia/qmediavideoprobecontrol.h>
-#include <QtMultimedia/qradiotunercontrol.h>
 #include <QtMultimedia/qaudiorecorder.h>
+#include <QtMultimedia/qradiotunercontrol.h>
 #include <QtMultimedia/qaudiooutputselectorcontrol.h>
 #include <QtMultimedia/qaudiodecodercontrol.h>
 #include <QtMultimedia/qcamera.h>
@@ -113,6 +116,7 @@
 #include <QtMultimedia/qmediaplaylist.h>
 #include <QtMultimedia/qcameraimagecapturecontrol.h>
 #include <QtMultimedia/qcameracapturebufferformatcontrol.h>
+#include <QtMultimedia/qcamerafocuscontrol.h>
 #include <QtMultimedia/qmediarecordercontrol.h>
 #include <QtMultimedia/qcameraimagecapture.h>
 #include <QtMultimedia/qaudioprobe.h>
@@ -182,122 +186,136 @@ enum : int {
     SBK_QCAMERA_STATUS_IDX                                   = 42,
     SBK_QCAMERA_STATE_IDX                                    = 41,
     SBK_QCAMERA_CAPTUREMODE_IDX                              = 34,
-    SBK_QFLAGS_QCAMERA_CAPTUREMODE_IDX                       = 69,
+    SBK_QFLAGS_QCAMERA_CAPTUREMODE_IDX                       = 81,
     SBK_QCAMERA_ERROR_IDX                                    = 35,
     SBK_QCAMERA_LOCKSTATUS_IDX                               = 38,
     SBK_QCAMERA_LOCKCHANGEREASON_IDX                         = 37,
     SBK_QCAMERA_LOCKTYPE_IDX                                 = 39,
-    SBK_QFLAGS_QCAMERA_LOCKTYPE_IDX                          = 70,
+    SBK_QFLAGS_QCAMERA_LOCKTYPE_IDX                          = 82,
     SBK_QCAMERA_POSITION_IDX                                 = 40,
     SBK_QCAMERA_FRAMERATERANGE_IDX                           = 36,
     SBK_QCAMERACAPTUREBUFFERFORMATCONTROL_IDX                = 43,
     SBK_QCAMERACAPTUREDESTINATIONCONTROL_IDX                 = 44,
     SBK_QCAMERACONTROL_IDX                                   = 45,
     SBK_QCAMERACONTROL_PROPERTYCHANGETYPE_IDX                = 46,
-    SBK_QCAMERAEXPOSURECONTROL_IDX                           = 47,
-    SBK_QCAMERAEXPOSURECONTROL_EXPOSUREPARAMETER_IDX         = 48,
-    SBK_QCAMERAFEEDBACKCONTROL_IDX                           = 49,
-    SBK_QCAMERAFEEDBACKCONTROL_EVENTTYPE_IDX                 = 50,
-    SBK_QCAMERAFOCUSZONE_IDX                                 = 51,
-    SBK_QCAMERAFOCUSZONE_FOCUSZONESTATUS_IDX                 = 52,
-    SBK_QCAMERAIMAGECAPTURE_IDX                              = 53,
-    SBK_QCAMERAIMAGECAPTURE_ERROR_IDX                        = 56,
-    SBK_QCAMERAIMAGECAPTURE_DRIVEMODE_IDX                    = 55,
-    SBK_QCAMERAIMAGECAPTURE_CAPTUREDESTINATION_IDX           = 54,
-    SBK_QFLAGS_QCAMERAIMAGECAPTURE_CAPTUREDESTINATION_IDX    = 71,
-    SBK_QCAMERAIMAGECAPTURECONTROL_IDX                       = 57,
-    SBK_QCAMERAIMAGEPROCESSINGCONTROL_IDX                    = 58,
-    SBK_QCAMERAIMAGEPROCESSINGCONTROL_PROCESSINGPARAMETER_IDX = 59,
-    SBK_QCAMERAINFO_IDX                                      = 60,
-    SBK_QCAMERAINFOCONTROL_IDX                               = 61,
-    SBK_QCAMERALOCKSCONTROL_IDX                              = 62,
-    SBK_QCAMERAVIEWFINDERSETTINGS_IDX                        = 63,
-    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL_IDX                 = 64,
-    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL_VIEWFINDERPARAMETER_IDX = 66,
-    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL2_IDX                = 65,
-    SBK_QCAMERAZOOMCONTROL_IDX                               = 67,
-    SBK_QCUSTOMAUDIOROLECONTROL_IDX                          = 68,
-    SBK_QIMAGEENCODERCONTROL_IDX                             = 75,
-    SBK_QIMAGEENCODERSETTINGS_IDX                            = 76,
-    SBK_QMEDIAAUDIOPROBECONTROL_IDX                          = 77,
-    SBK_QMEDIAAVAILABILITYCONTROL_IDX                        = 78,
-    SBK_QMEDIABINDABLEINTERFACE_IDX                          = 79,
-    SBK_QMEDIACONTAINERCONTROL_IDX                           = 80,
-    SBK_QMEDIACONTENT_IDX                                    = 81,
-    SBK_QMEDIACONTROL_IDX                                    = 82,
-    SBK_QMEDIAGAPLESSPLAYBACKCONTROL_IDX                     = 83,
-    SBK_QMEDIANETWORKACCESSCONTROL_IDX                       = 84,
-    SBK_QMEDIAOBJECT_IDX                                     = 85,
-    SBK_QMEDIAPLAYER_IDX                                     = 86,
-    SBK_QMEDIAPLAYER_STATE_IDX                               = 90,
-    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 89,
-    SBK_QMEDIAPLAYER_FLAG_IDX                                = 88,
-    SBK_QFLAGS_QMEDIAPLAYER_FLAG_IDX                         = 72,
-    SBK_QMEDIAPLAYER_ERROR_IDX                               = 87,
-    SBK_QMEDIAPLAYERCONTROL_IDX                              = 91,
-    SBK_QMEDIAPLAYLIST_IDX                                   = 92,
-    SBK_QMEDIAPLAYLIST_PLAYBACKMODE_IDX                      = 94,
-    SBK_QMEDIAPLAYLIST_ERROR_IDX                             = 93,
-    SBK_QMEDIARECORDER_IDX                                   = 95,
-    SBK_QMEDIARECORDER_STATE_IDX                             = 97,
-    SBK_QMEDIARECORDER_STATUS_IDX                            = 98,
-    SBK_QMEDIARECORDER_ERROR_IDX                             = 96,
-    SBK_QMEDIARECORDERCONTROL_IDX                            = 99,
-    SBK_QMEDIARESOURCE_IDX                                   = 100,
-    SBK_QMEDIASERVICE_IDX                                    = 101,
-    SBK_QMEDIASERVICECAMERAINFOINTERFACE_IDX                 = 102,
-    SBK_QMEDIASERVICEDEFAULTDEVICEINTERFACE_IDX              = 103,
-    SBK_QMEDIASERVICEFEATURESINTERFACE_IDX                   = 104,
-    SBK_QMEDIASERVICEPROVIDERHINT_IDX                        = 105,
-    SBK_QMEDIASERVICEPROVIDERHINT_TYPE_IDX                   = 107,
-    SBK_QMEDIASERVICEPROVIDERHINT_FEATURE_IDX                = 106,
-    SBK_QFLAGS_QMEDIASERVICEPROVIDERHINT_FEATURE_IDX         = 73,
-    SBK_QMEDIASERVICESUPPORTEDDEVICESINTERFACE_IDX           = 108,
-    SBK_QMEDIASERVICESUPPORTEDFORMATSINTERFACE_IDX           = 109,
-    SBK_QMEDIASTREAMSCONTROL_IDX                             = 110,
-    SBK_QMEDIASTREAMSCONTROL_STREAMTYPE_IDX                  = 111,
-    SBK_QMEDIATIMEINTERVAL_IDX                               = 112,
-    SBK_QMEDIATIMERANGE_IDX                                  = 113,
-    SBK_QMEDIAVIDEOPROBECONTROL_IDX                          = 114,
-    SBK_QMETADATAREADERCONTROL_IDX                           = 115,
-    SBK_QMETADATAWRITERCONTROL_IDX                           = 116,
-    SBK_QtMultimediaQMULTIMEDIA_IDX                          = 117,
-    SBK_QMULTIMEDIA_SUPPORTESTIMATE_IDX                      = 121,
-    SBK_QMULTIMEDIA_ENCODINGQUALITY_IDX                      = 120,
-    SBK_QMULTIMEDIA_ENCODINGMODE_IDX                         = 119,
-    SBK_QMULTIMEDIA_AVAILABILITYSTATUS_IDX                   = 118,
-    SBK_QRADIODATA_IDX                                       = 122,
-    SBK_QRADIODATA_ERROR_IDX                                 = 123,
-    SBK_QRADIODATA_PROGRAMTYPE_IDX                           = 124,
-    SBK_QRADIODATACONTROL_IDX                                = 125,
-    SBK_QRADIOTUNER_IDX                                      = 126,
-    SBK_QRADIOTUNER_STATE_IDX                                = 130,
-    SBK_QRADIOTUNER_BAND_IDX                                 = 127,
-    SBK_QRADIOTUNER_ERROR_IDX                                = 128,
-    SBK_QRADIOTUNER_STEREOMODE_IDX                           = 131,
-    SBK_QRADIOTUNER_SEARCHMODE_IDX                           = 129,
-    SBK_QRADIOTUNERCONTROL_IDX                               = 132,
-    SBK_QSOUND_IDX                                           = 133,
-    SBK_QSOUND_LOOP_IDX                                      = 134,
-    SBK_QSOUNDEFFECT_IDX                                     = 135,
-    SBK_QSOUNDEFFECT_LOOP_IDX                                = 136,
-    SBK_QSOUNDEFFECT_STATUS_IDX                              = 137,
-    SBK_QVIDEODEVICESELECTORCONTROL_IDX                      = 138,
-    SBK_QVIDEOENCODERSETTINGS_IDX                            = 139,
-    SBK_QVIDEOENCODERSETTINGSCONTROL_IDX                     = 140,
-    SBK_QVIDEOFILTERRUNNABLE_IDX                             = 141,
-    SBK_QVIDEOFILTERRUNNABLE_RUNFLAG_IDX                     = 142,
-    SBK_QFLAGS_QVIDEOFILTERRUNNABLE_RUNFLAG_IDX              = 74,
-    SBK_QVIDEOFRAME_IDX                                      = 143,
-    SBK_QVIDEOFRAME_FIELDTYPE_IDX                            = 144,
-    SBK_QVIDEOFRAME_PIXELFORMAT_IDX                          = 145,
-    SBK_QVIDEOPROBE_IDX                                      = 146,
-    SBK_QVIDEORENDERERCONTROL_IDX                            = 147,
-    SBK_QVIDEOSURFACEFORMAT_IDX                              = 148,
-    SBK_QVIDEOSURFACEFORMAT_DIRECTION_IDX                    = 149,
-    SBK_QVIDEOSURFACEFORMAT_YCBCRCOLORSPACE_IDX              = 150,
-    SBK_QVIDEOWINDOWCONTROL_IDX                              = 151,
-    SBK_QtMultimedia_IDX_COUNT                               = 152
+    SBK_QCAMERAEXPOSURE_IDX                                  = 47,
+    SBK_QCAMERAEXPOSURE_FLASHMODE_IDX                        = 49,
+    SBK_QFLAGS_QCAMERAEXPOSURE_FLASHMODE_IDX                 = 83,
+    SBK_QCAMERAEXPOSURE_EXPOSUREMODE_IDX                     = 48,
+    SBK_QCAMERAEXPOSURE_METERINGMODE_IDX                     = 50,
+    SBK_QCAMERAEXPOSURECONTROL_IDX                           = 51,
+    SBK_QCAMERAEXPOSURECONTROL_EXPOSUREPARAMETER_IDX         = 52,
+    SBK_QCAMERAFEEDBACKCONTROL_IDX                           = 53,
+    SBK_QCAMERAFEEDBACKCONTROL_EVENTTYPE_IDX                 = 54,
+    SBK_QCAMERAFLASHCONTROL_IDX                              = 55,
+    SBK_QCAMERAFOCUS_IDX                                     = 56,
+    SBK_QCAMERAFOCUS_FOCUSMODE_IDX                           = 57,
+    SBK_QFLAGS_QCAMERAFOCUS_FOCUSMODE_IDX                    = 84,
+    SBK_QCAMERAFOCUS_FOCUSPOINTMODE_IDX                      = 58,
+    SBK_QCAMERAFOCUSCONTROL_IDX                              = 59,
+    SBK_QCAMERAFOCUSZONE_IDX                                 = 60,
+    SBK_QCAMERAFOCUSZONE_FOCUSZONESTATUS_IDX                 = 61,
+    SBK_QCAMERAIMAGECAPTURE_IDX                              = 62,
+    SBK_QCAMERAIMAGECAPTURE_ERROR_IDX                        = 65,
+    SBK_QCAMERAIMAGECAPTURE_DRIVEMODE_IDX                    = 64,
+    SBK_QCAMERAIMAGECAPTURE_CAPTUREDESTINATION_IDX           = 63,
+    SBK_QFLAGS_QCAMERAIMAGECAPTURE_CAPTUREDESTINATION_IDX    = 85,
+    SBK_QCAMERAIMAGECAPTURECONTROL_IDX                       = 66,
+    SBK_QCAMERAIMAGEPROCESSING_IDX                           = 67,
+    SBK_QCAMERAIMAGEPROCESSING_WHITEBALANCEMODE_IDX          = 69,
+    SBK_QCAMERAIMAGEPROCESSING_COLORFILTER_IDX               = 68,
+    SBK_QCAMERAIMAGEPROCESSINGCONTROL_IDX                    = 70,
+    SBK_QCAMERAIMAGEPROCESSINGCONTROL_PROCESSINGPARAMETER_IDX = 71,
+    SBK_QCAMERAINFO_IDX                                      = 72,
+    SBK_QCAMERAINFOCONTROL_IDX                               = 73,
+    SBK_QCAMERALOCKSCONTROL_IDX                              = 74,
+    SBK_QCAMERAVIEWFINDERSETTINGS_IDX                        = 75,
+    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL_IDX                 = 76,
+    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL_VIEWFINDERPARAMETER_IDX = 78,
+    SBK_QCAMERAVIEWFINDERSETTINGSCONTROL2_IDX                = 77,
+    SBK_QCAMERAZOOMCONTROL_IDX                               = 79,
+    SBK_QCUSTOMAUDIOROLECONTROL_IDX                          = 80,
+    SBK_QIMAGEENCODERCONTROL_IDX                             = 89,
+    SBK_QIMAGEENCODERSETTINGS_IDX                            = 90,
+    SBK_QMEDIAAUDIOPROBECONTROL_IDX                          = 91,
+    SBK_QMEDIAAVAILABILITYCONTROL_IDX                        = 92,
+    SBK_QMEDIABINDABLEINTERFACE_IDX                          = 93,
+    SBK_QMEDIACONTAINERCONTROL_IDX                           = 94,
+    SBK_QMEDIACONTENT_IDX                                    = 95,
+    SBK_QMEDIACONTROL_IDX                                    = 96,
+    SBK_QMEDIAGAPLESSPLAYBACKCONTROL_IDX                     = 97,
+    SBK_QMEDIANETWORKACCESSCONTROL_IDX                       = 98,
+    SBK_QMEDIAOBJECT_IDX                                     = 99,
+    SBK_QMEDIAPLAYER_IDX                                     = 100,
+    SBK_QMEDIAPLAYER_STATE_IDX                               = 104,
+    SBK_QMEDIAPLAYER_MEDIASTATUS_IDX                         = 103,
+    SBK_QMEDIAPLAYER_FLAG_IDX                                = 102,
+    SBK_QFLAGS_QMEDIAPLAYER_FLAG_IDX                         = 86,
+    SBK_QMEDIAPLAYER_ERROR_IDX                               = 101,
+    SBK_QMEDIAPLAYERCONTROL_IDX                              = 105,
+    SBK_QMEDIAPLAYLIST_IDX                                   = 106,
+    SBK_QMEDIAPLAYLIST_PLAYBACKMODE_IDX                      = 108,
+    SBK_QMEDIAPLAYLIST_ERROR_IDX                             = 107,
+    SBK_QMEDIARECORDER_IDX                                   = 109,
+    SBK_QMEDIARECORDER_STATE_IDX                             = 111,
+    SBK_QMEDIARECORDER_STATUS_IDX                            = 112,
+    SBK_QMEDIARECORDER_ERROR_IDX                             = 110,
+    SBK_QMEDIARECORDERCONTROL_IDX                            = 113,
+    SBK_QMEDIARESOURCE_IDX                                   = 114,
+    SBK_QMEDIASERVICE_IDX                                    = 115,
+    SBK_QMEDIASERVICECAMERAINFOINTERFACE_IDX                 = 116,
+    SBK_QMEDIASERVICEDEFAULTDEVICEINTERFACE_IDX              = 117,
+    SBK_QMEDIASERVICEFEATURESINTERFACE_IDX                   = 118,
+    SBK_QMEDIASERVICEPROVIDERHINT_IDX                        = 119,
+    SBK_QMEDIASERVICEPROVIDERHINT_TYPE_IDX                   = 121,
+    SBK_QMEDIASERVICEPROVIDERHINT_FEATURE_IDX                = 120,
+    SBK_QFLAGS_QMEDIASERVICEPROVIDERHINT_FEATURE_IDX         = 87,
+    SBK_QMEDIASERVICESUPPORTEDDEVICESINTERFACE_IDX           = 122,
+    SBK_QMEDIASERVICESUPPORTEDFORMATSINTERFACE_IDX           = 123,
+    SBK_QMEDIASTREAMSCONTROL_IDX                             = 124,
+    SBK_QMEDIASTREAMSCONTROL_STREAMTYPE_IDX                  = 125,
+    SBK_QMEDIATIMEINTERVAL_IDX                               = 126,
+    SBK_QMEDIATIMERANGE_IDX                                  = 127,
+    SBK_QMEDIAVIDEOPROBECONTROL_IDX                          = 128,
+    SBK_QMETADATAREADERCONTROL_IDX                           = 129,
+    SBK_QMETADATAWRITERCONTROL_IDX                           = 130,
+    SBK_QtMultimediaQMULTIMEDIA_IDX                          = 131,
+    SBK_QMULTIMEDIA_SUPPORTESTIMATE_IDX                      = 135,
+    SBK_QMULTIMEDIA_ENCODINGQUALITY_IDX                      = 134,
+    SBK_QMULTIMEDIA_ENCODINGMODE_IDX                         = 133,
+    SBK_QMULTIMEDIA_AVAILABILITYSTATUS_IDX                   = 132,
+    SBK_QRADIODATA_IDX                                       = 136,
+    SBK_QRADIODATA_ERROR_IDX                                 = 137,
+    SBK_QRADIODATA_PROGRAMTYPE_IDX                           = 138,
+    SBK_QRADIODATACONTROL_IDX                                = 139,
+    SBK_QRADIOTUNER_IDX                                      = 140,
+    SBK_QRADIOTUNER_STATE_IDX                                = 144,
+    SBK_QRADIOTUNER_BAND_IDX                                 = 141,
+    SBK_QRADIOTUNER_ERROR_IDX                                = 142,
+    SBK_QRADIOTUNER_STEREOMODE_IDX                           = 145,
+    SBK_QRADIOTUNER_SEARCHMODE_IDX                           = 143,
+    SBK_QRADIOTUNERCONTROL_IDX                               = 146,
+    SBK_QSOUND_IDX                                           = 147,
+    SBK_QSOUND_LOOP_IDX                                      = 148,
+    SBK_QSOUNDEFFECT_IDX                                     = 149,
+    SBK_QSOUNDEFFECT_LOOP_IDX                                = 150,
+    SBK_QSOUNDEFFECT_STATUS_IDX                              = 151,
+    SBK_QVIDEODEVICESELECTORCONTROL_IDX                      = 152,
+    SBK_QVIDEOENCODERSETTINGS_IDX                            = 153,
+    SBK_QVIDEOENCODERSETTINGSCONTROL_IDX                     = 154,
+    SBK_QVIDEOFILTERRUNNABLE_IDX                             = 155,
+    SBK_QVIDEOFILTERRUNNABLE_RUNFLAG_IDX                     = 156,
+    SBK_QFLAGS_QVIDEOFILTERRUNNABLE_RUNFLAG_IDX              = 88,
+    SBK_QVIDEOFRAME_IDX                                      = 157,
+    SBK_QVIDEOFRAME_FIELDTYPE_IDX                            = 158,
+    SBK_QVIDEOFRAME_PIXELFORMAT_IDX                          = 159,
+    SBK_QVIDEOPROBE_IDX                                      = 160,
+    SBK_QVIDEORENDERERCONTROL_IDX                            = 161,
+    SBK_QVIDEOSURFACEFORMAT_IDX                              = 162,
+    SBK_QVIDEOSURFACEFORMAT_DIRECTION_IDX                    = 163,
+    SBK_QVIDEOSURFACEFORMAT_YCBCRCOLORSPACE_IDX              = 164,
+    SBK_QVIDEOWINDOWCONTROL_IDX                              = 165,
+    SBK_QtMultimedia_IDX_COUNT                               = 166
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtMultimediaTypes;
@@ -323,15 +341,16 @@ enum : int {
     SBK_QTMULTIMEDIA_QLIST_QCAMERA_FRAMERATERANGE_IDX        = 10, // QList<QCamera::FrameRateRange >
     SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 11, // QList<QSize >
     SBK_QTMULTIMEDIA_QLIST_QCAMERAVIEWFINDERSETTINGS_IDX     = 12, // QList<QCameraViewfinderSettings >
-    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 13, // QList<QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERAINFO_IDX                   = 14, // QList<QCameraInfo >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIARESOURCE_IDX                = 15, // const QList<QMediaResource > &
-    SBK_QTMULTIMEDIA_QLIST_QNETWORKCONFIGURATION_IDX         = 16, // const QList<QNetworkConfiguration > &
-    SBK_QTMULTIMEDIA_QLIST_QMEDIACONTENT_IDX                 = 17, // const QList<QMediaContent > &
-    SBK_QTMULTIMEDIA_QLIST_QREAL_IDX                         = 18, // QList<qreal >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMEINTERVAL_IDX            = 19, // QList<QMediaTimeInterval >
-    SBK_QTMULTIMEDIA_QPAIR_INT_INT_IDX                       = 20, // QPair<int,int >
-    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 21
+    SBK_QTMULTIMEDIA_QLIST_QREAL_IDX                         = 13, // QList<qreal >
+    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 14, // QList<QVariant >
+    SBK_QTMULTIMEDIA_QLIST_QCAMERAFOCUSZONE_IDX              = 15, // QList<QCameraFocusZone >
+    SBK_QTMULTIMEDIA_QLIST_QCAMERAINFO_IDX                   = 16, // QList<QCameraInfo >
+    SBK_QTMULTIMEDIA_QLIST_QMEDIARESOURCE_IDX                = 17, // const QList<QMediaResource > &
+    SBK_QTMULTIMEDIA_QLIST_QNETWORKCONFIGURATION_IDX         = 18, // const QList<QNetworkConfiguration > &
+    SBK_QTMULTIMEDIA_QLIST_QMEDIACONTENT_IDX                 = 19, // const QList<QMediaContent > &
+    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMEINTERVAL_IDX            = 20, // QList<QMediaTimeInterval >
+    SBK_QTMULTIMEDIA_QPAIR_INT_INT_IDX                       = 21, // QPair<int,int >
+    SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 22
 };
 // Macros for type check
 
@@ -339,6 +358,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAbstractAudioDeviceInfo >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QABSTRACTAUDIODEVICEINFO_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAbstractAudioInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QABSTRACTAUDIOINPUT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAbstractAudioOutput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QABSTRACTAUDIOOUTPUT_IDX]); }
@@ -387,10 +408,21 @@ template<> inline PyTypeObject *SbkType< ::QCameraCaptureBufferFormatControl >()
 template<> inline PyTypeObject *SbkType< ::QCameraCaptureDestinationControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERACAPTUREDESTINATIONCONTROL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraControl::PropertyChangeType >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERACONTROL_PROPERTYCHANGETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERACONTROL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCameraExposure::FlashMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURE_FLASHMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QCameraExposure::FlashMode> >() { return SbkPySide2_QtMultimediaTypes[SBK_QFLAGS_QCAMERAEXPOSURE_FLASHMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraExposure::ExposureMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURE_EXPOSUREMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraExposure::MeteringMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURE_METERINGMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraExposure >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraExposureControl::ExposureParameter >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURECONTROL_EXPOSUREPARAMETER_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraExposureControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAEXPOSURECONTROL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraFeedbackControl::EventType >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFEEDBACKCONTROL_EVENTTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraFeedbackControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFEEDBACKCONTROL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCameraFlashControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFLASHCONTROL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCameraFocus::FocusMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUS_FOCUSMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QCameraFocus::FocusMode> >() { return SbkPySide2_QtMultimediaTypes[SBK_QFLAGS_QCAMERAFOCUS_FOCUSMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraFocus::FocusPointMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUS_FOCUSPOINTMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraFocus >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCameraFocusControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUSCONTROL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraFocusZone::FocusZoneStatus >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUSZONE_FOCUSZONESTATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraFocusZone >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAFOCUSZONE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraImageCapture::Error >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGECAPTURE_ERROR_IDX]; }
@@ -399,6 +431,9 @@ template<> inline PyTypeObject *SbkType< ::QCameraImageCapture::CaptureDestinati
 template<> inline PyTypeObject *SbkType< ::QFlags<QCameraImageCapture::CaptureDestination> >() { return SbkPySide2_QtMultimediaTypes[SBK_QFLAGS_QCAMERAIMAGECAPTURE_CAPTUREDESTINATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraImageCapture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGECAPTURE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraImageCaptureControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGECAPTURECONTROL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QCameraImageProcessing::WhiteBalanceMode >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGEPROCESSING_WHITEBALANCEMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraImageProcessing::ColorFilter >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGEPROCESSING_COLORFILTER_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QCameraImageProcessing >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGEPROCESSING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraImageProcessingControl::ProcessingParameter >() { return SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGEPROCESSINGCONTROL_PROCESSINGPARAMETER_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QCameraImageProcessingControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAIMAGEPROCESSINGCONTROL_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QCameraInfo >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QCAMERAINFO_IDX]); }
@@ -489,6 +524,7 @@ template<> inline PyTypeObject *SbkType< ::QVideoSurfaceFormat::Direction >() {
 template<> inline PyTypeObject *SbkType< ::QVideoSurfaceFormat::YCbCrColorSpace >() { return SbkPySide2_QtMultimediaTypes[SBK_QVIDEOSURFACEFORMAT_YCBCRCOLORSPACE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoSurfaceFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QVIDEOSURFACEFORMAT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoWindowControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaTypes[SBK_QVIDEOWINDOWCONTROL_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
