@@ -65,7 +65,7 @@
 #include <QtQuick/qsgsimplerectnode.h>
 #include <QtQuick/qquickitemgrabresult.h>
 #include <QtQuick/qsgsimpletexturenode.h>
-#include <QtQuick/qsgmaterial.h>
+#include <QtQuick/qsgmaterialtype.h>
 #include <QtQuick/qquickrendercontrol.h>
 #include <QtQuick/qsggeometry.h>
 #include <QtQuick/qsgnode.h>
@@ -93,75 +93,78 @@
 
 // Type indices
 enum : int {
-    SBK_QQUICKASYNCIMAGEPROVIDER_IDX                         = 8,
-    SBK_QQUICKFRAMEBUFFEROBJECT_IDX                          = 9,
-    SBK_QQUICKFRAMEBUFFEROBJECT_RENDERER_IDX                 = 10,
-    SBK_QQUICKIMAGEPROVIDER_IDX                              = 11,
-    SBK_QQUICKIMAGERESPONSE_IDX                              = 12,
-    SBK_QQUICKITEM_IDX                                       = 13,
-    SBK_QQUICKITEM_FLAG_IDX                                  = 14,
+    SBK_QQUICKASYNCIMAGEPROVIDER_IDX                         = 9,
+    SBK_QQUICKFRAMEBUFFEROBJECT_IDX                          = 10,
+    SBK_QQUICKFRAMEBUFFEROBJECT_RENDERER_IDX                 = 11,
+    SBK_QQUICKIMAGEPROVIDER_IDX                              = 12,
+    SBK_QQUICKIMAGERESPONSE_IDX                              = 13,
+    SBK_QQUICKITEM_IDX                                       = 14,
+    SBK_QQUICKITEM_FLAG_IDX                                  = 15,
     SBK_QFLAGS_QQUICKITEM_FLAG_IDX                           = 0,
-    SBK_QQUICKITEM_ITEMCHANGE_IDX                            = 15,
-    SBK_QQUICKITEM_TRANSFORMORIGIN_IDX                       = 16,
-    SBK_QQUICKITEM_UPDATEPAINTNODEDATA_IDX                   = 17,
-    SBK_QQUICKITEMGRABRESULT_IDX                             = 18,
-    SBK_QQUICKPAINTEDITEM_IDX                                = 19,
-    SBK_QQUICKPAINTEDITEM_RENDERTARGET_IDX                   = 21,
-    SBK_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX                = 20,
+    SBK_QQUICKITEM_ITEMCHANGE_IDX                            = 16,
+    SBK_QQUICKITEM_TRANSFORMORIGIN_IDX                       = 17,
+    SBK_QQUICKITEM_UPDATEPAINTNODEDATA_IDX                   = 18,
+    SBK_QQUICKITEMGRABRESULT_IDX                             = 19,
+    SBK_QQUICKPAINTEDITEM_IDX                                = 20,
+    SBK_QQUICKPAINTEDITEM_RENDERTARGET_IDX                   = 22,
+    SBK_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX                = 21,
     SBK_QFLAGS_QQUICKPAINTEDITEM_PERFORMANCEHINT_IDX         = 1,
-    SBK_QQUICKRENDERCONTROL_IDX                              = 22,
-    SBK_QQUICKTEXTDOCUMENT_IDX                               = 23,
-    SBK_QQUICKTEXTUREFACTORY_IDX                             = 24,
-    SBK_QQUICKTRANSFORM_IDX                                  = 25,
-    SBK_QQUICKVIEW_IDX                                       = 26,
-    SBK_QQUICKVIEW_RESIZEMODE_IDX                            = 27,
-    SBK_QQUICKVIEW_STATUS_IDX                                = 28,
-    SBK_QQUICKWINDOW_IDX                                     = 29,
-    SBK_QQUICKWINDOW_CREATETEXTUREOPTION_IDX                 = 30,
+    SBK_QQUICKRENDERCONTROL_IDX                              = 23,
+    SBK_QQUICKTEXTDOCUMENT_IDX                               = 24,
+    SBK_QQUICKTEXTUREFACTORY_IDX                             = 25,
+    SBK_QQUICKTRANSFORM_IDX                                  = 26,
+    SBK_QQUICKVIEW_IDX                                       = 27,
+    SBK_QQUICKVIEW_RESIZEMODE_IDX                            = 28,
+    SBK_QQUICKVIEW_STATUS_IDX                                = 29,
+    SBK_QQUICKWINDOW_IDX                                     = 30,
+    SBK_QQUICKWINDOW_CREATETEXTUREOPTION_IDX                 = 31,
     SBK_QFLAGS_QQUICKWINDOW_CREATETEXTUREOPTION_IDX          = 2,
-    SBK_QQUICKWINDOW_RENDERSTAGE_IDX                         = 31,
-    SBK_QQUICKWINDOW_SCENEGRAPHERROR_IDX                     = 32,
-    SBK_QQUICKWINDOW_TEXTRENDERTYPE_IDX                      = 33,
-    SBK_QSGABSTRACTRENDERER_IDX                              = 34,
-    SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX                 = 35,
+    SBK_QQUICKWINDOW_RENDERSTAGE_IDX                         = 33,
+    SBK_QQUICKWINDOW_SCENEGRAPHERROR_IDX                     = 34,
+    SBK_QQUICKWINDOW_TEXTRENDERTYPE_IDX                      = 35,
+    SBK_QQUICKWINDOW_NATIVEOBJECTTYPE_IDX                    = 32,
+    SBK_QSGABSTRACTRENDERER_IDX                              = 36,
+    SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX                 = 37,
     SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX          = 3,
-    SBK_QSGBASICGEOMETRYNODE_IDX                             = 36,
-    SBK_QSGCLIPNODE_IDX                                      = 37,
-    SBK_QSGDYNAMICTEXTURE_IDX                                = 38,
-    SBK_QSGENGINE_IDX                                        = 39,
-    SBK_QSGENGINE_CREATETEXTUREOPTION_IDX                    = 40,
-    SBK_QFLAGS_QSGENGINE_CREATETEXTUREOPTION_IDX             = 4,
-    SBK_QSGGEOMETRY_IDX                                      = 41,
-    SBK_QSGGEOMETRY_ATTRIBUTETYPE_IDX                        = 44,
-    SBK_QSGGEOMETRY_DATAPATTERN_IDX                          = 46,
-    SBK_QSGGEOMETRY_DRAWINGMODE_IDX                          = 47,
-    SBK_QSGGEOMETRY_TYPE_IDX                                 = 50,
-    SBK_QSGGEOMETRY_ATTRIBUTE_IDX                            = 42,
-    SBK_QSGGEOMETRY_ATTRIBUTESET_IDX                         = 43,
-    SBK_QSGGEOMETRY_COLOREDPOINT2D_IDX                       = 45,
-    SBK_QSGGEOMETRY_POINT2D_IDX                              = 48,
-    SBK_QSGGEOMETRY_TEXTUREDPOINT2D_IDX                      = 49,
-    SBK_QSGGEOMETRYNODE_IDX                                  = 51,
-    SBK_QSGMATERIALTYPE_IDX                                  = 52,
-    SBK_QSGNODE_IDX                                          = 53,
-    SBK_QSGNODE_NODETYPE_IDX                                 = 56,
-    SBK_QSGNODE_FLAG_IDX                                     = 55,
-    SBK_QFLAGS_QSGNODE_FLAG_IDX                              = 6,
-    SBK_QSGNODE_DIRTYSTATEBIT_IDX                            = 54,
-    SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX                     = 5,
-    SBK_QSGOPACITYNODE_IDX                                   = 57,
-    SBK_QSGSIMPLERECTNODE_IDX                                = 58,
-    SBK_QSGSIMPLETEXTURENODE_IDX                             = 59,
-    SBK_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 60,
-    SBK_QFLAGS_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 7,
-    SBK_QSGTEXTURE_IDX                                       = 61,
-    SBK_QSGTEXTURE_WRAPMODE_IDX                              = 64,
-    SBK_QSGTEXTURE_FILTERING_IDX                             = 63,
-    SBK_QSGTEXTURE_ANISOTROPYLEVEL_IDX                       = 62,
-    SBK_QSGTEXTUREPROVIDER_IDX                               = 65,
-    SBK_QSGTRANSFORMNODE_IDX                                 = 66,
-    SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX              = 68, // QSharedPointer<QQuickItemGrabResult >
-    SBK_QtQuick_IDX_COUNT                                    = 69
+    SBK_QSGABSTRACTRENDERER_MATRIXTRANSFORMFLAG_IDX          = 38,
+    SBK_QFLAGS_QSGABSTRACTRENDERER_MATRIXTRANSFORMFLAG_IDX   = 4,
+    SBK_QSGBASICGEOMETRYNODE_IDX                             = 39,
+    SBK_QSGCLIPNODE_IDX                                      = 40,
+    SBK_QSGDYNAMICTEXTURE_IDX                                = 41,
+    SBK_QSGENGINE_IDX                                        = 42,
+    SBK_QSGENGINE_CREATETEXTUREOPTION_IDX                    = 43,
+    SBK_QFLAGS_QSGENGINE_CREATETEXTUREOPTION_IDX             = 5,
+    SBK_QSGGEOMETRY_IDX                                      = 44,
+    SBK_QSGGEOMETRY_ATTRIBUTETYPE_IDX                        = 47,
+    SBK_QSGGEOMETRY_DATAPATTERN_IDX                          = 49,
+    SBK_QSGGEOMETRY_DRAWINGMODE_IDX                          = 50,
+    SBK_QSGGEOMETRY_TYPE_IDX                                 = 53,
+    SBK_QSGGEOMETRY_ATTRIBUTE_IDX                            = 45,
+    SBK_QSGGEOMETRY_ATTRIBUTESET_IDX                         = 46,
+    SBK_QSGGEOMETRY_COLOREDPOINT2D_IDX                       = 48,
+    SBK_QSGGEOMETRY_POINT2D_IDX                              = 51,
+    SBK_QSGGEOMETRY_TEXTUREDPOINT2D_IDX                      = 52,
+    SBK_QSGGEOMETRYNODE_IDX                                  = 54,
+    SBK_QSGMATERIALTYPE_IDX                                  = 55,
+    SBK_QSGNODE_IDX                                          = 56,
+    SBK_QSGNODE_NODETYPE_IDX                                 = 59,
+    SBK_QSGNODE_FLAG_IDX                                     = 58,
+    SBK_QFLAGS_QSGNODE_FLAG_IDX                              = 7,
+    SBK_QSGNODE_DIRTYSTATEBIT_IDX                            = 57,
+    SBK_QFLAGS_QSGNODE_DIRTYSTATEBIT_IDX                     = 6,
+    SBK_QSGOPACITYNODE_IDX                                   = 60,
+    SBK_QSGSIMPLERECTNODE_IDX                                = 61,
+    SBK_QSGSIMPLETEXTURENODE_IDX                             = 62,
+    SBK_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 63,
+    SBK_QFLAGS_QSGSIMPLETEXTURENODE_TEXTURECOORDINATESTRANSFORMFLAG_IDX = 8,
+    SBK_QSGTEXTURE_IDX                                       = 64,
+    SBK_QSGTEXTURE_WRAPMODE_IDX                              = 67,
+    SBK_QSGTEXTURE_FILTERING_IDX                             = 66,
+    SBK_QSGTEXTURE_ANISOTROPYLEVEL_IDX                       = 65,
+    SBK_QSGTEXTUREPROVIDER_IDX                               = 68,
+    SBK_QSGTRANSFORMNODE_IDX                                 = 69,
+    SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX              = 71, // QSharedPointer<QQuickItemGrabResult >
+    SBK_QtQuick_IDX_COUNT                                    = 72
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_QtQuickTypes;
@@ -179,9 +182,9 @@ enum : int {
     SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 2, // QList<QByteArray >
     SBK_QTQUICK_QVECTOR_INT_IDX                              = 3, // const QVector<int > &
     SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 4, // QList<QQmlError >
-    SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 5, // QList<QVariant >
-    SBK_QTQUICK_QLIST_QSTRING_IDX                            = 6, // QList<QString >
-    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 7, // QMap<QString,QVariant >
+    SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // const QMap<QString,QVariant > &
+    SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 6, // QList<QVariant >
+    SBK_QTQUICK_QLIST_QSTRING_IDX                            = 7, // QList<QString >
     SBK_QtQuick_CONVERTERS_IDX_COUNT                         = 8
 };
 // Macros for type check
@@ -190,6 +193,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QQuickAsyncImageProvider >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QQUICKASYNCIMAGEPROVIDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickFramebufferObject >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QQUICKFRAMEBUFFEROBJECT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QQuickFramebufferObject::Renderer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QQUICKFRAMEBUFFEROBJECT_RENDERER_IDX]); }
@@ -218,9 +223,12 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QQuickWindow::CreateTextureOpt
 template<> inline PyTypeObject *SbkType< ::QQuickWindow::RenderStage >() { return SbkPySide2_QtQuickTypes[SBK_QQUICKWINDOW_RENDERSTAGE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQuickWindow::SceneGraphError >() { return SbkPySide2_QtQuickTypes[SBK_QQUICKWINDOW_SCENEGRAPHERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQuickWindow::TextRenderType >() { return SbkPySide2_QtQuickTypes[SBK_QQUICKWINDOW_TEXTRENDERTYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QQuickWindow::NativeObjectType >() { return SbkPySide2_QtQuickTypes[SBK_QQUICKWINDOW_NATIVEOBJECTTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QQuickWindow >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QQUICKWINDOW_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGAbstractRenderer::ClearModeBit >() { return SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QSGAbstractRenderer::ClearModeBit> >() { return SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_CLEARMODEBIT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QSGAbstractRenderer::MatrixTransformFlag >() { return SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_MATRIXTRANSFORMFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QSGAbstractRenderer::MatrixTransformFlag> >() { return SbkPySide2_QtQuickTypes[SBK_QFLAGS_QSGABSTRACTRENDERER_MATRIXTRANSFORMFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSGAbstractRenderer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSGABSTRACTRENDERER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGBasicGeometryNode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSGBASICGEOMETRYNODE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGClipNode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSGCLIPNODE_IDX]); }
@@ -258,6 +266,7 @@ template<> inline PyTypeObject *SbkType< ::QSGTexture >() { return reinterpret_c
 template<> inline PyTypeObject *SbkType< ::QSGTextureProvider >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSGTEXTUREPROVIDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSGTransformNode >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSGTRANSFORMNODE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSharedPointer<QQuickItemGrabResult > >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtQuickTypes[SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
