@@ -1,8 +1,11 @@
+from __future__ import print_function
+
+
 __all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;Positioning;Location;Qml;Quick;QuickWidgets;Scxml;Script;ScriptTools;Sensors;TextToSpeech;Charts;Svg;DataVisualization;UiTools;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
+    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLFunctions;Positioning;Location;Qml;Quick;QuickWidgets;RemoteObjects;Scxml;Script;ScriptTools;Sensors;TextToSpeech;Charts;Svg;DataVisualization;UiTools;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "5.12.1"
-__version_info__ = (5, 12, 1, "", "")
+__version__ = "5.14.1"
+__version_info__ = (5, 14, 1, "", "")
 
 def _setupQtDirectories():
     import sys
@@ -18,7 +21,16 @@ def _setupQtDirectories():
     # the libshiboken library location. Importing the module
     # loads the libraries into the process memory beforehand, and
     # thus takes care of it for us.
-    import shiboken2
+    try:
+        import shiboken2
+    except Exception:
+        paths = ', '.join(sys.path)
+        print('PySide2/__init__.py: Unable to import shiboken2 from {}'.format(paths),
+              file=sys.stderr)
+        raise
+
+    #   Trigger signature initialization.
+    type.__signature__
 
     pyside_package_dir =  os.path.abspath(os.path.dirname(__file__))
 
